@@ -3,11 +3,11 @@ test_that("Errors fail gracefully", {
 })
 
 test_that("cNNI()", {
-  tr <- Preorder(root(TreeTools::BalancedTree(letters[1:7]), 'a', resolve.root = TRUE))
+  tr <- Preorder(root(TreeTools::BalancedTree(letters[1:7]), "a", resolve.root = TRUE))
   expect_equal(ape::read.tree(text="(a,(b,((c,d),((e,g),f))));"),
-               cNNI(tr, 0, 1)) # Edge '9'
+               cNNI(tr, 0, 1)) # Edge "9"
   expect_equal(ape::read.tree(text="(a,(b,((c,d),((f,g),e))));"),
-               cNNI(tr, 0, 0)) # Edge '9'
+               cNNI(tr, 0, 0)) # Edge "9"
   expect_equal(cNNI(tr, 0, 1), cNNI(tr, 4, 1))
   expect_equal(ape::read.tree(text="(a, (b, (g, ((c, d), (e, f)))));"), # Edge 8
                cNNI(tr, 1, 1))
@@ -19,7 +19,7 @@ test_that("cNNI()", {
                cNNI(tr, 2, 1))
   expect_equal(ape::read.tree(text="(a, ((b, (c, d)), ((e, f), g)));"), # Edge 4
                cNNI(tr, 3, 1))
-  suppressWarnings(RNGversion('3.5.0'))
+  suppressWarnings(RNGversion("3.5.0"))
   set.seed(0) # sample.int gives 4, 1
   expect_equal(cNNI(tr, 0, 1), cNNI(tr))
-})
\ No newline at end of file
+})
